@@ -13,7 +13,7 @@
    Copyright 2022, HSPyLib team
 """
 from hspylib.modules.application.exit_status import ExitStatus
-from hspylib.modules.cli.vt100.terminal import Terminal
+from hspylib.modules.cli.terminal import Terminal
 from typing import Tuple
 
 
