@@ -27,9 +27,6 @@ class UriScheme(Enumeration):
     HTTPS       = 'https'
     FTP         = 'ftp'
     FILE        = 'file'
-    LOCAL       = 'localhost'
-    LOOPBACK    = '127.0.0.1'
-    CATCH_ALL   = '0.0.0.0'
     # fmt: on
 
     @classmethod
