@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.hspylib.modules.qt.promotions
+   @package: hspylib.modules.qt.promotions
       @file: hcombobox.py
    @created: Wed, 30 Jun 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
